/* 
 * tkMacAppInit.c --
 *
 *	Provides a version of the Tcl_AppInit procedure for the example shell.
 *
 * Copyright 1993-1994 Lockheed Missle & Space Company, AI Center
 * Copyright (c) 1995 Sun Microsystems, Inc.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

static char sccsid[] = "@(#) tkMacAppInit.c 1.9 95/09/11 09:55:18";

#include "tcl.h"
#include "tclInt.h"
#include "tclPort.h"

#ifdef TK_TEST
EXTERN int		TkTest_Init _ANSI_ARGS_((Tcl_Interp *interp));
#endif /* TK_TEST */

/*
 *----------------------------------------------------------------------
 *
 * Tcl_AppInit --
 *
 *	This procedure performs application-specific initialization.
 *	Most applications, especially those that incorporate additional
 *	packages, will have their own version of this procedure.
 *
 * Results:
 *	Returns a standard Tcl completion code, and leaves an error
 *	message in interp->result if an error occurs.
 *
 * Side effects:
 *	Depends on the startup script.
 *
 *----------------------------------------------------------------------
 */

int
Tcl_AppInit(interp)
    Tcl_Interp *interp;		/* Interpreter for application. */
{
    if (Tcl_Init(interp) == TCL_ERROR) {
	return TCL_ERROR;
    }

#ifdef TK_TEST
    if (TkTest_Init(interp) == TCL_ERROR) {
	return TCL_ERROR;
    }
#endif /* TK_TEST */
	
    /*
     * Call the init procedures for included packages.  Each call should
     * look like this:
     *
     * if (Mod_Init(interp) == TCL_ERROR) {
     *     return TCL_ERROR;
     * }
     *
     * where "Mod" is the name of the module.
     */

    /*
     * Call Tcl_CreateCommand for application-specific commands, if
     * they weren't already created by the init procedures called above.
     */

    /*
     * Specify a user-specific startup file to invoke if the application
     * is run interactively.  Typically the startup file is "~/.apprc"
     * where "app" is the name of the application.  If this line is deleted
     * then no user-specific startup file will be run under any conditions.
     */

    if (Tcl_Eval(interp, "source -rsrc {tk}") == TCL_ERROR) {
	return TCL_ERROR;
    }
    if (Tcl_Eval(interp, "source -rsrc {button}") == TCL_ERROR) {
	return TCL_ERROR;
    }
    if (Tcl_Eval(interp, "source -rsrc {dialog}") == TCL_ERROR) {
	return TCL_ERROR;
    }
    if (Tcl_Eval(interp, "source -rsrc {entry}") == TCL_ERROR) {
	return TCL_ERROR;
    }
    if (Tcl_Eval(interp, "source -rsrc {focus}") == TCL_ERROR) {
	return TCL_ERROR;
    }
    if (Tcl_Eval(interp, "source -rsrc {listbox}") == TCL_ERROR) {
	return TCL_ERROR;
    }
    if (Tcl_Eval(interp, "source -rsrc {menu}") == TCL_ERROR) {
	return TCL_ERROR;
    }
    if (Tcl_Eval(interp, "source -rsrc {palette}") == TCL_ERROR) {
	return TCL_ERROR;
    }
    if (Tcl_Eval(interp, "source -rsrc {scale}") == TCL_ERROR) {
	return TCL_ERROR;
    }
    if (Tcl_Eval(interp, "source -rsrc {scrollbar}") == TCL_ERROR) {
	return TCL_ERROR;
    }
    if (Tcl_Eval(interp, "source -rsrc {tearoff}") == TCL_ERROR) {
	return TCL_ERROR;
    }
    if (Tcl_Eval(interp, "source -rsrc {text}") == TCL_ERROR) {
	return TCL_ERROR;
    }
    if (Tcl_Eval(interp, "source -rsrc {tkerror}") == TCL_ERROR) {
	return TCL_ERROR;
    }

    /* tcl_RcFileName = "~/.tclshrc"; */
    return TCL_OK;
}
